Class: Yoomoney::Models::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate
- Inherits:
-
Yoomoney::Models::PaymentMethodData
- Object
- Internal::Type::BaseModel
- Yoomoney::Models::PaymentMethodData
- Yoomoney::Models::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate
- Defined in:
- lib/yoomoney/models/payment_create_params.rb
Defined Under Namespace
Classes: Article, ElectronicCertificate
Instance Attribute Summary collapse
- #articles ⇒ Array<Yoomoney::Models::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate::Article>?
- #electronic_certificate ⇒ Yoomoney::Models::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate::ElectronicCertificate?
Attributes inherited from Yoomoney::Models::PaymentMethodData
Instance Method Summary collapse
-
#initialize(article_name:, article_number:, price:, quantity:, tru_code:, article_code: nil, metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Article for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(article_name:, article_number:, price:, quantity:, tru_code:, article_code: nil, metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see Article for more details.
|
|
# File 'lib/yoomoney/models/payment_create_params.rb', line 409
|
Instance Attribute Details
#articles ⇒ Array<Yoomoney::Models::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate::Article>?
356 357 |
# File 'lib/yoomoney/models/payment_create_params.rb', line 356 optional :articles, -> { Yoomoney::Internal::Type::ArrayOf[Yoomoney::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate::Article] } |
#electronic_certificate ⇒ Yoomoney::Models::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate::ElectronicCertificate?
362 363 |
# File 'lib/yoomoney/models/payment_create_params.rb', line 362 optional :electronic_certificate, -> { Yoomoney::PaymentCreateParams::PaymentMethodData::PaymentMethodDataElectronicCertificate::ElectronicCertificate } |